# Copyright 2022 The KerasCV Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from keras_cv.models.csp_darknet import CSPDarkNet
from keras_cv.models.darknet import DarkNet21
from keras_cv.models.darknet import DarkNet53
from keras_cv.models.densenet import DenseNet121
from keras_cv.models.densenet import DenseNet169
from keras_cv.models.densenet import DenseNet201
from keras_cv.models.mlp_mixer import MLPMixerB16
from keras_cv.models.mlp_mixer import MLPMixerB32
from keras_cv.models.mlp_mixer import MLPMixerL16
from keras_cv.models.vgg19 import VGG19
